%
%  World Vector Shoreline 

% The preceding empty line is important
% $Log: wvs1.m,v $
% Revision 1.1.2.1  2000/09/13 22:16:49  edavis
% Synch with new 3.2.x version from URI.
%
% Revision 1.2  2000/01/31 18:23:42  kwoklin
% Move server to 'maewest'.   klee
%
% Revision 1.1  1999/11/29 17:28:24  kwoklin
% Adding World Vector Shoreline as a data set.  klee
%

% $Id: wvs1.m,v 1.1.2.1 2000/09/13 22:16:49 edavis Exp $
% klee 11/26/99

GetFunctionName = 'getwvs';
Server = 'http://maewest.gso.uri.edu/cgi-bin/nph-jg/wvs';
CatalogServer = 'annual';
URL_m_File = 'wvsu';

LonRange = [-77 -52];
LatRange = [37 52];
TimeRange = [1800 2000];
DepthRange = [0.0 0.0];
Resolution = nan;

DodsName = str2mat('shoreline');
DataName = 'ShoreLine - World Vector Shoreline (1:250,000) - DMA/NIMA';
LongitudeName = 'lon';
LatitudeName = 'lat';
TimeName = '';          
DepthName = '';
DepthUnits = '';
SelectableVariables = str2mat('ShoreLine');
UmbrellaDods = str2mat('lat','lon');
UmbrellaVariables = str2mat('ShortLine_Lat','ShortLine_Lon');

DataNull=[nan nan nan nan -9999 -9999];

Acknowledge = sprintf('%s\n%s\n%s\n\n%s', ...
    [ 'The authors of this data set are E.A. Soluri and V.A. Woodson.'],...
    [ 'The original source of data is from Defense Mapping Agency'],...
      '(DMA) (now National Imagery and Mapping Agency (NIMA))',...
    [ 'The data were provided by the U. S. Geological Survey,',...
      'Woods Hole Field Center at Woods Hole, Massachusetts,',...
      '(http://crusty.er.usgs.gov/coast/getcoast.html),',...
      'and accessed via the Distributed Oceanographic ',...
      'Data System (DODS: http://www.unidata.ucar.edu/packages/dods).'], ...
    [ 'Citations: E.A. Soluri and V.A. Woodson 1990 World ',...
      'Vector Shoreline. International Hydrographic Review, ',...
      'LXVII(1)']);
Data_Use_Policy = [];

%COMMENTS
Comments1 = sprintf('%s\n',...
'   ',...
'                     World Vector Shoreline (1:250,000)' ,...
'   ',...
 '           Parameter         Description                    Units',...
'      --------------------------------------------------------------------------',...
'            lat               Latitude                       degrees north',...
'            lon               Longitude                      degrees east',...
'   ',...
'World Vector Shoreline ',...
'   ',...
'    Original source of data: Defense Mapping Agency (DMA) (now National Imagery and ',...
'      Mapping Agency (NIMA)) . ',...
'    World-wide coverage ',...
'    Suitable for scales close to 250,000 ',...
'    Accuracy; requirement for this data is that 90% of all identifiable shoreline ',...
'      features be located within 500 meters (2.0mm at 1:250,000) cirular error of ',...
'      their true geographic positions with respect to the preferred datum (WGS 84). ',...
'    Horizontal Datum - World Geodetic System (WGS 84) ',...
'    Vertical Datum - shoreline based on Mean High Water (MHW) ',...
'    The WVS coastline data is available on NGDC''s "Global Relief" CD-ROM, along with ',...
'      the now-anchient WDBII political bounds and rivers. ',...
'   ',...
'Note: The version of WVS used in the coastline extractor does not include all the ',...
'      features (such as lakes, rivers,bradwaters,glaciers, international boundaries, ',...
'      country names, etc.) that DMA has in their data set. ',...
'   ',...
'SUMMARY: ',...
'  The World Vector Shoreline (WVS) is a digital data file at a nominal scale of ',...
'1:250000, containing the shorelines, international boundaries and country names of ',...
'the world. The World Vector Shoreline is a standard US Defense Mapping Agency (DMA) ',...
'product that has been designed for use in many applications. The WVS is divided into ',...
'ten ocean basin area files. Together the ten files form a seamless world, with the ',...
'exception of Central America, where there is an overlap between the Western North ',...
'Atlantic file and the Eastern North Pacific File.',...
'   ',...
'  The main source material for the WVS was the DMA''s Digital Landmass Blanking (DLMB)',...
'data which was derived primarily from the Joint Operations Graphics and coastal ',...
'nautical charts produced by DMA. The DLMB data consists of a land/water flag file on',...
'a 3 by 3 arc-second interval grid. This raster data set was converted into vector form ',...
'to create the WVS. For areas of the world not covered by the DLMB data (e.g. the Arctic',...
'and Antarctic), the shoreline was taken from the best available hard copy sources at ',...
'a preferred scale of 1:250000. The WVS data are stored in chain-node format, and ',...
'include tags to indicate the landside/waterside of the shoreline.',...
'   ',...
'REFERENCE: ',...
'  E.A. Soluri and V.A. Woodson 1990 World Vector Shoreline. International ',...
'Hydrographic Review, LXVII(1)');

Comments2 = sprintf('%s\n', ...
'   ', ...
'    Spatial_Domain = ', ...
'         Bounding Coordinates: ', ...
'              West Bounding Coordinate:  77 W ', ...
'              East Bounding Coordinate:  52 W ', ...
'              South Bounding Coordinate: 37 N ', ...
'              North Bounding Coordinate: 52 N ', ...
'   ', ...
'    Point_of_Contact = ', ...
'         Address - si: ', ...
'               Rich Signell', ...
'               384 Woods Hole Road', ...
'               U.S. Geological Survey', ...
'               Woods Hole, MA 02543 ', ...
'               USA ', ...
'               Electronic Mail Address: INTERNET > rsignell@crusty.er.usgs.gov ', ...
'               Web Page URL: http://crusty.er.usgs.gov/rsignell.html ', ...
'         Address - dods: ',...
'               Electronic Mail Address: INTERNET > support@unidata.ucar.edu ');

Comments = [Comments1 Comments2];


